@@ -69,6 +69,10 @@ class SVGLayer():
 	def __init__(self, group_node):
 		self._node = group_node
 
+	@property
+	def label(self):
+		return self._node.getAttribute("inkscape:label")
+
 	@property
 	def layer_id(self):
 		return self._node.getAttribute("id")
